## S3 method for class 'matrix':
ranking(x, y, kernel ="rbfdot", kpar = list(sigma = 1), scale = TRUE,
alpha = 0.99, iterations = 600, edgegraph = FALSE, convergence = FALSE ,...)sigmainverse kernel width for the Radial Balpha parameter takes values between 0 and 1
and is used to control the authoritative scores received from the
unlabeled points. For 0 no global structure is found the algorithm
ranks the points similarly to the original distaranking which extends the matrix
class.
The first column of the returned matrix contains the original index of
the points in the data matrix the second column contains the final
score received by each point and the third column the ranking of the point.
The object contains the following slots :ranking-class, speccdata(spirals)
## create data set to be ranked
ran<-spirals[rowSums(abs(spirals)<0.55)==2,]
## rank points according to "relevance" to point 54 (up left)
ranked<-ranking(ran,54,kernel="rbfdot",kpar=list(sigma=100),edgegraph=TRUE)
ranked[54,2] <- max(ranked[-54,2])
plot(ran,col=hsv(ranked[,2]/ranked[54,2],1,1))Run the code above in your browser using DataLab